@@ -6,8 +6,9 @@ import os
 import random
 from glob import glob
 from .extracteur import ExtracteurDeJus
-from play_sounds import play_file
-from pathlib import PurePath
+from playsound import playsound
+from pathlib import Path
+import time
 directory = os.path.dirname(os.path.abspath(__file__))
 
 
@@ -19,7 +20,11 @@ class nectar(ExtracteurDeJus):
         self.failure_files = glob(os.path.join(directory, 'Sounds', 'Kaamelott', 'Echec', '*.wav'))
 
     def success(self):
-        play_file(PurePath(random.choice(self.success_files)))
+        p = Path(random.choice(self.success_files), encoding=None)
+        playsound(str(p), False)
+        time.sleep(1)
 
     def failure(self):
-        play_file(PurePath(random.choice(self.failure_files)))
+        p = Path(random.choice(self.failure_files), encoding=None)
+        playsound(str(p), False)
+        time.sleep(1)
